 - Name Project: MatchWork
 - Team: Calenzo
 - Start day: 11/05/2022

- Objetivos:
    - Esse projeto tem como principal objetivo treinar minhas habilidades com a linguagem Python.

- Práticas:
    - Clean architecture;
    - Clean code;
    - Microservice;